@@ -6,7 +6,7 @@ use vars qw($VERSION);
 
 use if $] < 5.008 => "IO::Scalar";
 
-$VERSION = '1.61';
+$VERSION = '1.62';
 
 =head1 NAME
 
@@ -125,7 +125,7 @@ for a new, custom configuration.
 
 =item -l
 
-List all installed modules wth their versions
+List all installed modules with their versions
 
 =item -L author [ author ... ]
 
@@ -397,7 +397,7 @@ sub _process_setup_options
 
 Just do it.
 
-The C<run> method returns 0 on success and a postive number on
+The C<run> method returns 0 on success and a positive number on
 failure. See the section on EXIT CODES for details on the values.
 
 =cut
@@ -859,9 +859,10 @@ sub _print_ping_report
 	my( $mirror ) = @_;
 
 	my $rtt = eval { _get_ping_report( $mirror ) };
+	my $result = $rtt ? sprintf "+ (%4d ms)", $rtt * 1000 : '!';
 
 	$logger->info(
-		sprintf "\t%s (%4d ms) %s", $rtt  ? '+' : '!',  $rtt * 1000, $mirror
+		sprintf "\t%s %s", $result, $mirror
 		);
 	}
 
@@ -965,6 +966,7 @@ sub _dump_config # -J
 
 	my $fh = $args->[0] || \*STDOUT;
 
+	local $Data::Dumper::Sortkeys = 1;
 	my $dd = Data::Dumper->new(
 		[$CPAN::Config],
 		['$CPAN::Config']
@@ -1156,9 +1158,9 @@ sub _show_Details
 		print "$arg\n", "-" x 73, "\n\t";
 		print join "\n\t",
 			$module->description ? $module->description : "(no description)",
-			$module->cpan_file,
-			$module->inst_file,
-			'Installed: ' . $module->inst_version,
+			$module->cpan_file ? $module->cpan_file : "(no cpanfile)",
+			$module->inst_file ? $module->inst_file :"(no installation file)" ,
+			'Installed: ' . ($module->inst_version ? $module->inst_version : "not installed"),
 			'CPAN:      ' . $module->cpan_version . '  ' .
 				($module->uptodate ? "" : "Not ") . "up to date",
 			$author->fullname . " (" . $module->userid . ")",
